#!/bin/bash

#stop operation if an error occurred
set -e

DATE=$(date +"%Y%m%d%H%M")
KEY=/opt/tcr/key.prv


function self_ip {
    echo `ip route get 8.8.8.8 | grep src | awk '{ print $7 }'`
}

FILENAME=$DATE"_"`self_ip`

function get_devices {
    CMD=
    DEVS=`ip link show | grep UP | grep -v lo | awk -F: '{ print $2 }'`
    for dev in $DEVS;
    do
        CMD="$CMD -i $dev"
    done
    echo $CMD
}

function start_capture {
    DURATION=$1
    HOST=$2

    /usr/sbin/tshark -f "tcp && host $HOST" `get_devices` -a duration:$DURATION -Q -w /tmp/$FILENAME"_in.pcap" &
    /usr/sbin/tshark -f "tcp && !host $HOST" `get_devices` -s 100 -a duration:$DURATION -Q -w /tmp/$FILENAME".pcap" &
}

########################################################################################################

if [ $# -ne 3 ]; then
  echo "Usage: $0 <timeout> <client-host> <full-path>"
  exit 1
fi

DURATION=$1
HOST=$2
DESTPATH=$3

#start tshark
start_capture $DURATION $HOST $DESTPATH

#wait far all processes
for job in `jobs -p`
do
    wait $job
done

#package as tar.gz
cd /tmp
TMP="$DATE*"
FILES=`ls $TMP`
PACKAGE_NAME=$FILENAME".tar.gz"
/bin/tar czf $PACKAGE_NAME $FILES 2> /dev/null

/bin/chmod 400 $KEY

#copy package
/bin/scp -i $KEY -oStrictHostKeyChecking=no /tmp/$PACKAGE_NAME "root@$DESTPATH"

#remove SSH key
/bin/rm $KEY


